
# Slot: model_taxon

The primary taxon term for the model, over the NCBITaxon:subClassOf relationship type. This is used to determine the primary taxon that the model is relevant to.

URI: [gocam:queryIndex__model_taxon](https://w3id.org/gocam/queryIndex__model_taxon)


## Domain and Range

None &#8594;  <sub>0..\*</sub> [TermObject](TermObject.md)

## Parents


## Children


## Used by

 * [QueryIndex](QueryIndex.md)
